@@ -6,7 +6,7 @@ from google.cloud import tasks_v2
 from .task import Task
 
 
-class TaskBackend(Protocol):
+class Backend(Protocol):
     def run(self, task: Task):
         ...
 
@@ -18,12 +18,13 @@ class ThreadingBackend:
 
 
 class CloudTasksBackend:
-    def __init__(self, project, location, queue, base_url, service_account):
+    def __init__(self, project, location, queue, base_url, service_account, audience):
         self.project = project
         self.location = location
         self.queue = queue
         self.base_url = base_url
         self.service_account = service_account
+        self.audience = audience
 
     def run(self, task: Task):
         client = tasks_v2.CloudTasksClient()
@@ -38,7 +39,7 @@ class CloudTasksBackend:
                 "url": self.base_url + task.fully_qualified_name,
                 "oidc_token": {
                     "service_account_email": self.service_account,
-                    "audience": "rhombus",
+                    "audience": self.audience,
                 },
                 "body": task.params.json(),
             }
