@@ -32,9 +32,9 @@ class TaskMeta(abc.ABCMeta):
             handler.__name__ = name
 
             # register HTTP handler
-            router.post(f"/{name}", auth=settings.TASKS_API_AUTHENTICATION)(
-                csrf_exempt(handler)
-            )
+            router.post(
+                f"/{name}", auth=getattr(settings, "TASKS_API_AUTHENTICATION", None)
+            )(csrf_exempt(handler))
 
         return cls
 
